# !/bin/bash
# Script to generate image-header as splash screen
# from image file (png or jpeg) defined by variable SPLASH_SCREEN

# Check if SPLASH_SCREEN variable is defined
if [ -z ${SPLASH_SCREEN+x} ]; then
    warning "SPLASH_SCREEN variable is not defined, use default background image"
    SPLASH_SCREEN="${srcDir}/background.png"
fi

# Check if splash screen image exists
if [ ! -f "${SPLASH_SCREEN}" ]; then
    fatal 1 "Splash screen file not found, please set the variable SPLASH_SCREEN to image file location"
fi

# Check if splash screen image format is supported
case $(basename $SPLASH_SCREEN) in
    *.png | *.jpeg)
        log "Splash screen file found: $SPLASH_SCREEN"
        ;;
    *)
        fatal 2 "Splash screen format not supported. Supported format: png, jpeg"
        ;;
esac

# Output file name
SPLASH_SCREEN_BASENAME="${SPLASH_SCREEN##*/}"
IMAGEH="${SPLASH_SCREEN_BASENAME%.*}-img.h"
POKY_IMG=psplash-poky-img.h

# Image header must be generated into source directory
cd ${srcDir}

# convert SPLASH_SCREEN into IMAGEH
log_exec ./make-image-header.sh ${SPLASH_SCREEN} POKY

# replace poky image header with our new one
log_exec cp ${IMAGEH} ${POKY_IMG}

cd -