# !/bin/bash

: ${HAS_UTMP:="false"}
: ${HAS_NETWORKD:="false"}
: ${HAS_RESOLVED:="false"}
: ${HAS_POLKIT:="false"}

systemd_unitdir=${sysconfdir}/system
base_bindir=/bin

log_exec install -d ${D}/${base_sbindir}

# Provide support for initramfs
[ ! -e ${D}/init ] && ln -s ${rootlibexecdir}/systemd/systemd ${D}/init
[ ! -e ${D}/${base_sbindir}/udevd ] && ln -s ${rootlibexecdir}/systemd/systemd-udevd ${D}/${base_sbindir}/udevd

log_exec install -d ${D}${sysconfdir}/udev/rules.d/
log_exec install -d ${D}${sysconfdir}/tmpfiles.d
log_exec install -m 0644 ${S}/*.rules ${D}${sysconfdir}/udev/rules.d/
log_exec install -d ${D}${libdir}/pkgconfig
log_exec install -m 0644 ${B}/src/udev/udev.pc ${D}${libdir}/pkgconfig/

log_exec install -m 0644 ${S}/00-create-volatile.conf ${D}${sysconfdir}/tmpfiles.d/

log_exec chown root:systemd-journal ${D}/var/log/journal

# Delete journal README, as log can be symlinked inside volatile.
log_exec rm -f ${D}/${localstatedir}/log/README

# journal-remote creates this at start
log_exec rm -rf ${D}/${localstatedir}/log/journal/remote

log_exec install -d ${D}${systemd_unitdir}/system/graphical.target.wants
log_exec install -d ${D}${systemd_unitdir}/system/multi-user.target.wants
log_exec install -d ${D}${systemd_unitdir}/system/poweroff.target.wants
log_exec install -d ${D}${systemd_unitdir}/system/reboot.target.wants
log_exec install -d ${D}${systemd_unitdir}/system/rescue.target.wants

# Create symlinks for systemd-update-utmp-runlevel.service
if [ "${HAS_UTMP}" = "true" ]; then
	ln -sf ../systemd-update-utmp-runlevel.service ${D}${systemd_unitdir}/system/graphical.target.wants/systemd-update-utmp-runlevel.service
	ln -sf ../systemd-update-utmp-runlevel.service ${D}${systemd_unitdir}/system/multi-user.target.wants/systemd-update-utmp-runlevel.service
	ln -sf ../systemd-update-utmp-runlevel.service ${D}${systemd_unitdir}/system/poweroff.target.wants/systemd-update-utmp-runlevel.service
	ln -sf ../systemd-update-utmp-runlevel.service ${D}${systemd_unitdir}/system/reboot.target.wants/systemd-update-utmp-runlevel.service
	ln -sf ../systemd-update-utmp-runlevel.service ${D}${systemd_unitdir}/system/rescue.target.wants/systemd-update-utmp-runlevel.service
fi

# this file is needed to exist if networkd is disabled but timesyncd is still in use since timesyncd checks it
# for existence else it fails
if [ -s ${D}${exec_prefix}/lib/tmpfiles.d/systemd.conf ]; then
	if ! ${HAS_NETWORKD}; then
		sed -i -e "\$ad /run/systemd/netif/links 0755 root root -" ${D}${exec_prefix}/lib/tmpfiles.d/systemd.conf
	fi
fi
if ! ${HAS_RESOLVED}; then
	echo 'L! ${sysconfdir}/resolv.conf - - - - ../run/systemd/resolve/resolv.conf' >>${D}${exec_prefix}/lib/tmpfiles.d/etc.conf
	echo 'd /run/systemd/resolve 0755 root root -' >>${D}${exec_prefix}/lib/tmpfiles.d/systemd.conf
	echo 'f /run/systemd/resolve/resolv.conf 0644 root root' >>${D}${exec_prefix}/lib/tmpfiles.d/systemd.conf
	ln -s ../run/systemd/resolve/resolv.conf ${D}${sysconfdir}/resolv-conf.systemd
else
	sed -i -e "s%^L! /etc/resolv.conf.*$%L! /etc/resolv.conf - - - - ../run/systemd/resolve/resolv.conf%g" ${D}${exec_prefix}/lib/tmpfiles.d/etc.conf
	ln -s ../run/systemd/resolve/resolv.conf ${D}${sysconfdir}/resolv-conf.systemd
fi
install -Dm 0755 ${S}/src/systemctl/systemd-sysv-install.SKELETON ${D}${systemd_unitdir}/systemd-sysv-install

# If polkit is setup fixup permissions and ownership
if ${HAS_POLKIT}; then
	if [ -d ${D}${datadir}/polkit-1/rules.d ]; then
		chmod 700 ${D}${datadir}/polkit-1/rules.d
		chown polkitd:root ${D}${datadir}/polkit-1/rules.d
	fi
fi

# conf files are handled by systemd-conf
log_exec rm -f ${D}${sysconfdir}/machine-id
log_exec rm -f ${D}${sysconfdir}/systemd/coredump.conf
log_exec rm -f ${D}${sysconfdir}/systemd/journald.conf
log_exec rm -f ${D}${sysconfdir}/systemd/logind.conf
log_exec rm -f ${D}${sysconfdir}/systemd/system.conf
log_exec rm -f ${D}${sysconfdir}/systemd/user.conf

# duplicate udevadm for postinst script
log_exec install -d ${D}${libexecdir}
log_exec ln ${D}${base_bindir}/udevadm ${D}${libexecdir}/${MLPREFIX}udevadm
